Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Reconciler ¶
type Reconciler struct {
GetCluster func(ctx context.Context, clusterName multicluster.ClusterName) (cluster.Cluster, error)
}
Reconciler reconciles a VirtualWorkspace object
func (*Reconciler) Reconcile ¶
func (r *Reconciler) Reconcile(ctx context.Context, req mcreconcile.Request) (res ctrl.Result, recErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
func (*Reconciler) SetupWithManager ¶
func (r *Reconciler) SetupWithManager(mgr mcmanager.Manager, opts ...mcbuilder.EngageOptions) error
SetupWithManager sets up the controller with the Manager.
Click to show internal directories.
Click to hide internal directories.