Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrMountNotFound = fmt.Errorf("mounted Secret or ConfigMap not found")
Functions ¶
func Capture ¶
func Capture[T ctrlruntimeclient.Object](out *[]T) reconciling.ObjectModifier
Capture appends the object of every ensured object through the reconciler chain to out. Objects that don't exist yet are empty objects.
func RelatedRevisionsLabels ¶
func RelatedRevisionsLabels(ctx context.Context, client ctrlruntimeclient.Client) reconciling.ObjectModifier
RelatedRevisionsLabels scans volume mounts for pod templates for ConfigMaps and Secrets and will then put new labels for these mounts onto the pod template, causing restarts when the volumes changed.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.